@orbit
Feature: Upload VM images with authentication
  In order to upload VM images to storage
  As a command line user
  I want to automatically convert and compress uploads to authenticated storage

  Background:
    Given a directory named "/tmp/uricp"
    And the default aruba timeout is 15 seconds
    And a container called "test_upload"

  Scenario: Direct Upload
    Given a 102400 byte file named "/tmp/uricp/srv-testy"
    When I store "img-testy" into container "test_upload" from "file:///tmp/uricp/srv-testy"
    Then a 102400 byte entry should exist in container "test_upload" called "img-testy"

  Scenario: Compressed Upload
    Given a 102400 byte file named "/tmp/uricp/srv-testy"
    When I store "img-testy" with options "--compress" into container "test_upload" from "file:///tmp/uricp/srv-testy" 
    Then an lz4 compressed entry should exist in container "test_upload" called "img-testy" 

  Scenario: Direct Upload with userid
    Given a 102400 byte file named "/tmp/uricp/srv-testa"
    When I store "img-testa" into container "test_upload" from "file:///tmp/uricp/srv-testa" with a userid
    Then a 102400 byte entry should exist in container "test_upload" called "img-testa"

  Scenario: Direct segmented Upload with userid
    Given a 102400 byte file named "/tmp/uricp/srv-testb"
    When I store "img-testb" with segment size "10kiB" into container "test_upload" from "file:///tmp/uricp/srv-testb" with a userid
    Then a 102400 byte entry should exist in container "test_upload" called "img-testb"
    And the container "test_upload" should contain 11 entries

  Scenario: Direct compressed segmented Upload with userid
    Given a 102400 byte file named "/tmp/uricp/srv-testc"
    When I store "img-testc" with segment size "10kiB" and options "--compress" into container "test_upload" from "file:///tmp/uricp/srv-testc" with a userid
    Then an lz4 compressed entry should exist in container "test_upload" called "img-testc" 

  Scenario: Direct segmented Upload with userid in qcow2 format
    Given a 102400 byte file named "/tmp/uricp/srv-testd"
    And the default aruba timeout is 60 seconds
    And a correctly initialised cache at "/tmp/uricp"
    When I store "img-testd" with segment size "10kiB" and options "--target-format 'qcow2' --cache /tmp/uricp" into container "test_upload" from "file:///tmp/uricp/srv-testd" with a userid
    Then a qcow2 entry should exist in container "test_upload" called "img-testd"

  Scenario: Direct segmented upload of lz4 file with userid in qcow2 format
    Given a 102400 byte lz4 file named "/tmp/uricp/srv-teste"
    And the default aruba timeout is 60 seconds
    And a correctly initialised cache at "/tmp/uricp"
    When I store "img-teste" with segment size "10kiB" and options "--target-format 'qcow2' --cache /tmp/uricp" into container "test_upload" from "file:///tmp/uricp/srv-teste" with a userid
    Then a qcow2 entry should exist in container "test_upload" called "img-teste"

  Scenario: Direct upload with userid of zero byte file.
    Given an empty file named "/tmp/uricp/srv-zerob"
    And the default aruba timeout is 60 seconds
    And a correctly initialised cache at "/tmp/uricp"
    When I store "img-zerob" with segment size "10kiB" and options "--target-format 'qcow2' --cache /tmp/uricp" into container "test_upload" from "file:///tmp/uricp/srv-zerob" with a userid
    Then a qcow2 entry should exist in container "test_upload" called "img-zerob"
